==> igniteui-react-charts-18.6.0.tgz: package/esm5/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var CategoryChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryChartToolbarProvider, _super);
    function CategoryChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.y = null;
        return _this;
    }
    CategoryChartToolbarProvider.prototype.e = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.acw != null;
                }
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.u = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "XAxisMajorStroke":
                this.f("ShowGridlines", 2, a.acw != null);
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.k = function (a, b) {
        var c = a;
        if (this.c(b, "ShowGridlines")) {
            if (c.acw == null) {
                if (this.y != null) {
                    c.acw = this.y;
                }
                else {
                    c.acw = c.dataChart.yc;
                }
            }
        }
        else {
            if (c.acw != null) {
                this.y = c.acw;
                c.acw = null;
            }
        }
    };
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
}(DomainChartToolbarProvider));
export { CategoryChartToolbarProvider };

==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var CategoryChartToolbarProvider = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryChartToolbarProvider, _super);
    function CategoryChartToolbarProvider() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ad = null;
        return _this;
    }
    CategoryChartToolbarProvider.prototype.g = function (a, b) {
        var c = a;
        switch (b.name) {
            case "ShowGridlines":
                {
                    var d = b;
                    d.isChecked = c.afu != null;
                }
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.z = function (a, b, c, d) {
        var e = a;
        switch (b) {
            case "XAxisMajorStroke":
                this.h("ShowGridlines", 2, a.afu != null);
                break;
        }
    };
    CategoryChartToolbarProvider.prototype.p = function (a, b) {
        var c = a;
        if (this.c(b, "ShowGridlines")) {
            if (c.afu == null) {
                if (this.ad != null) {
                    c.afu = this.ad;
                }
                else {
                    c.afu = c.dataChart.z6;
                }
            }
        }
        else {
            if (c.afu != null) {
                this.ad = c.afu;
                c.afu = null;
            }
        }
    };
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
}(DomainChartToolbarProvider));
export { CategoryChartToolbarProvider };
